#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-IkjVkklA1Sy4pw9WAkOigC
key:                  strict-list-0.1.7.6-IkjVkklA1Sy4pw9WAkOigC
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  a36b6596939390569e625869271b7e07
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-IkjVkklA1Sy4pw9WAkOigC
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-ISMWzeTPqg7GxJZ08wJoa
    semigroupoids-6.0.2-DkvMUiEEraN3sQtF6VOJ6h

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

